gchecky.model.demo_failure_t

Package gchecky :: Module model :: Class demo_failure_t |
[hide private]
[frames] | no frames]

# Class demo_failure_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    demo_failure_t

    >>> test_document(
    ...     demo_failure_t(message='Demo Failure Message')
    ... ,
    ...     '''<demo-failure xmlns="http://checkout.google.com/schema/2"
    ...                      message="Demo Failure Message" />'''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``demo-failure``'`` The document's unique xml tag name.
| message = `String:PATH(@message):REQ`
| _fields = ``{``'``message``'``:` String:PATH(@message):REQ`}`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`